@@ -2,10 +2,11 @@ library(sf)
 nc <- st_read(system.file("shape/nc.shp", package="sf"))
 poly_t <- st_sfc(st_polygon(list(rbind(c(10,-10), c(10,-20), c(20,-20),
                                        c(20,-10), c(10,-10)))),
-                 crs = 4326)
+                 crs = st_crs('OGC:CRS84'))
 
 test_that("projectUTM works with sfc_POLYGON", {
-  expect_equal(st_crs(projectUTM(st_cast(nc[1,], "POLYGON")))[["input"]],
+  expect_equal(st_crs(projectUTM(st_cast(st_geometry(nc[1,]),
+                                         "POLYGON")))[["input"]],
                "+proj=utm +zone=17")
 })
 
@@ -15,11 +16,14 @@ test_that("projectUTM works with sfc_MULTIPOLYGON", {
 
 
 test_that("projectUTM works with sfc_POINT", {
-  expect_equal(st_crs(projectUTM(st_centroid(nc)))[["input"]], "+proj=utm +zone=17")
+  expect_equal(st_crs(projectUTM(st_centroid(st_geometry(nc))))[["input"]],
+               "+proj=utm +zone=17")
 })
 
 test_that("projectUTM works with sfc_POINT", {
-  expect_equal(st_crs(projectUTM(st_cast(st_centroid(nc), 'MULTIPOINT')))[["input"]], "+proj=utm +zone=17")
+  expect_equal(st_crs(projectUTM(st_cast(st_centroid(st_geometry(nc)),
+                                         'MULTIPOINT')))[["input"]],
+               "+proj=utm +zone=17")
 })
 
 test_that("projectUTM works with southern latitude", {
